==> kimageannotator_0.5.1.orig.tar.gz: kImageAnnotator-0.5.1/translations/kImageAnnotator_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hans">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>排序</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>置于顶层</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>上移一层</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>下移一层</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>置于底层</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>选中当前</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation type="unfinished">颜色</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation type="unfinished">文本颜色</translation>
    </message>
    <message>
        <source>Width</source>
        <translation type="unfinished">宽度</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation type="unfinished">模糊系数</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>关闭其它</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>关闭全部</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>关闭左侧</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>关闭右侧</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>边框和填充可见性</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>有边框且有填充</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>有边框且无填充</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>无边框且无填充</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation type="unfinished">字体大小</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>滤镜</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>无滤镜</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>阴影</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>描边</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation type="unfinished">宽度：</translation>
    </message>
    <message>
        <source>H:</source>
        <translation type="unfinished">高度：</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Flip</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>缩放图像</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>保持长宽比</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>像素</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>百分比</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>贴纸</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>笔</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>数字</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>高亮矩形区域</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>高亮椭圆区域</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>高亮笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭头</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>双箭头</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>线段</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>模糊</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>数字标注</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>贴纸</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>像素化</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>文字标注</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>文字箭头标注</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>数字箭头标注</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kimageannotator_0.5.2.orig.tar.gz: kImageAnnotator-0.5.2/translations/kImageAnnotator_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_Hans">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>排序</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>置于顶层</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>上移一层</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>下移一层</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>置于底层</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>选中当前</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>通用设置</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>图像设置</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>颜色</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>文本颜色</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>当前数字</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>模糊系数</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>项影</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>元素设置</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>关闭其它</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>关闭全部</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>关闭左侧</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>关闭右侧</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>工具选择</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>开启</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>边框和填充可见性</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>有边框且有填充</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>有边框且无填充</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>无边框且无填充</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>字体大小</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>粗体</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>下划线</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>滤镜</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>无滤镜</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>阴影</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>描边</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>反转色</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>颜色：</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>画布背景色</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>旋转图片</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>顺时针旋转90°</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>逆时针旋转90°</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>水平</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>垂直</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>旋转</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>反转</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>缩放图像</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>保持长宽比</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>宽度：</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>高度：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>像素</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>百分比</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>贴纸</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>选择</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>笔</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>数字</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>高亮矩形区域</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>高亮椭圆区域</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>高亮笔</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>箭头</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>双箭头</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>线段</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>模糊</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>矩形</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>椭圆</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>数字标注</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>贴纸</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>像素化</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>文字标注</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>文字箭头标注</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>数字箭头标注</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>复制</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>放大（%1）</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>缩小（%1）</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>重置大小（%1）</translation>
    </message>
</context>
</TS>
